@@ -61,6 +61,15 @@ static const char *icons[] = {
   NULL
 };
 
+/* Icons for different recording levels */
+static const char *recording_icons[] = {
+  "microphone-sensitivity-muted-symbolic",
+  "microphone-sensitivity-low-symbolic",
+  "microphone-sensitivity-medium-symbolic",
+  "microphone-sensitivity-high-symbolic",
+  NULL
+};
+
 
 
 static void                 pulseaudio_button_finalize        (GObject            *object);
@@ -68,6 +77,11 @@ static gboolean             pulseaudio_button_button_press    (GtkWidget
                                                                GdkEventButton     *event);
 static gboolean             pulseaudio_button_scroll_event    (GtkWidget          *widget,
                                                                GdkEventScroll     *event);
+static gboolean             pulseaudio_query_tooltip          (GtkWidget          *widget,
+                                                               gint                x,
+                                                               gint                y,
+                                                               gboolean            keyboard_mode,
+                                                               GtkTooltip         *tooltip);
 static void                 pulseaudio_button_menu_deactivate (PulseaudioButton   *button,
                                                                GtkMenuShell       *menu);
 static void                 pulseaudio_button_update_icons    (PulseaudioButton   *button);
@@ -91,10 +105,12 @@ struct _PulseaudioButton
   /* Icon size currently used */
   gint                  icon_size;
   const gchar          *icon_name;
+  const gchar          *recording_icon_name;
 
   PulseaudioMenu       *menu;
 
   gulong                volume_changed_id;
+  gulong                recording_volume_changed_id;
   gulong                recording_changed_id;
   gulong                deactivate_id;
 };
@@ -120,6 +136,7 @@ pulseaudio_button_class_init (PulseaudioButtonClass *klass)
   gtkwidget_class = GTK_WIDGET_CLASS (klass);
   gtkwidget_class->button_press_event   = pulseaudio_button_button_press;
   gtkwidget_class->scroll_event         = pulseaudio_button_scroll_event;
+  gtkwidget_class->query_tooltip        = pulseaudio_query_tooltip;
 }
 
 
@@ -137,6 +154,7 @@ pulseaudio_button_init (PulseaudioButton *button)
   gtk_button_set_use_underline (GTK_BUTTON (button), TRUE);
   gtk_widget_set_focus_on_click (GTK_WIDGET (button), FALSE);
   gtk_widget_set_name (GTK_WIDGET (button), "pulseaudio-button");
+  gtk_widget_set_has_tooltip (GTK_WIDGET (button), TRUE);
 
   /* Preload icons */
   g_signal_connect (G_OBJECT (button), "style-updated", G_CALLBACK (pulseaudio_button_update_icons), button);
@@ -160,10 +178,12 @@ pulseaudio_button_init (PulseaudioButton *button)
 
   button->menu = NULL;
   button->volume_changed_id = 0;
+  button->recording_volume_changed_id = 0;
+  button->recording_changed_id = 0;
   button->deactivate_id = 0;
 
   button->image = gtk_image_new ();
-  button->recording_indicator = gtk_image_new_from_icon_name ("audio-input-microphone-symbolic", GTK_ICON_SIZE_MENU);
+  button->recording_indicator = gtk_image_new ();
   box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_container_add (GTK_CONTAINER (button), box);
   gtk_box_pack_start (GTK_BOX (box), GTK_WIDGET (button->recording_indicator), TRUE, FALSE, 0);
@@ -204,6 +224,19 @@ pulseaudio_button_finalize (GObject *object)
 
 
 
+static gboolean
+pulseaudio_button_mic_icon_under_pointer (PulseaudioButton *button,
+                                          gdouble           pointer_pos_x)
+{
+  if (!pulseaudio_volume_get_recording (button->volume))
+    return FALSE;
+
+  /* Microphone icon is on the left */
+  return (pointer_pos_x / (gdouble) gtk_widget_get_allocated_width (GTK_WIDGET (button))) < 0.5;
+}
+
+
+
 static gboolean
 pulseaudio_button_button_press (GtkWidget      *widget,
                                 GdkEventButton *event)
@@ -244,7 +277,10 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
   if (event->button == 2) /* middle button */
     {
-      pulseaudio_volume_toggle_muted (button->volume);
+      if (pulseaudio_button_mic_icon_under_pointer (button, event->x))
+        pulseaudio_volume_toggle_muted_mic (button->volume);
+      else
+        pulseaudio_volume_toggle_muted (button->volume);
       return TRUE;
     }
 
@@ -257,7 +293,8 @@ static gboolean
 pulseaudio_button_scroll_event (GtkWidget *widget, GdkEventScroll *event)
 {
   PulseaudioButton *button      = PULSEAUDIO_BUTTON (widget);
-  gdouble           volume      = pulseaudio_volume_get_volume (button->volume);
+  gboolean          is_mic      = pulseaudio_button_mic_icon_under_pointer (button, event->x);
+  gdouble           volume      = is_mic ? pulseaudio_volume_get_volume_mic (button->volume) : pulseaudio_volume_get_volume (button->volume);
   gdouble           volume_step = pulseaudio_config_get_volume_step (button->config) / 100.0;
   gdouble           new_volume;
 
@@ -268,7 +305,56 @@ pulseaudio_button_scroll_event (GtkWidget *widget, GdkEventScroll *event)
   else
     new_volume = volume;
 
-  pulseaudio_volume_set_volume (button->volume, new_volume);
+  if (is_mic)
+    pulseaudio_volume_set_volume_mic (button->volume, new_volume);
+  else
+    pulseaudio_volume_set_volume (button->volume, new_volume);
+
+  return TRUE;
+}
+
+
+
+static gboolean
+pulseaudio_query_tooltip (GtkWidget  *widget,
+                          gint        x,
+                          gint        y,
+                          gboolean    keyboard_mode,
+                          GtkTooltip *tooltip)
+{
+  PulseaudioButton *button = PULSEAUDIO_BUTTON (widget);
+  gchar            *tip_text;
+  gboolean          muted;
+  gdouble           volume;
+
+  if (keyboard_mode)
+    return FALSE;
+
+  if (!pulseaudio_volume_get_connected (button->volume))
+    {
+      tip_text = g_strdup_printf (_("Not connected to the PulseAudio server"));
+    }
+  else
+    {
+      if (pulseaudio_button_mic_icon_under_pointer (button, x))
+        {
+          muted = pulseaudio_volume_get_muted_mic (button->volume);
+          volume = pulseaudio_volume_get_volume_mic (button->volume);
+        }
+      else
+        {
+          muted = pulseaudio_volume_get_muted (button->volume);
+          volume = pulseaudio_volume_get_volume (button->volume);
+        }
+
+      if (muted)
+        tip_text = g_strdup_printf (_("Volume %d%% (muted)"), (gint) round (volume * 100));
+      else
+        tip_text = g_strdup_printf (_("Volume %d%%"), (gint) round (volume * 100));
+    }
+
+  gtk_tooltip_set_text (tooltip, tip_text);
+  g_free (tip_text);
 
   return TRUE;
 }
@@ -331,12 +417,14 @@ pulseaudio_button_update (PulseaudioButton *button,
                           gboolean          force_update)
 {
   gdouble      volume;
+  gdouble      recording_volume;
   gboolean     connected;
   gboolean     sink_connected;
   gboolean     muted;
+  gboolean     recording_muted;
   gboolean     recording;
-  gchar       *tip_text;
   const gchar *icon_name;
+  const gchar *recording_icon_name;
 
   g_return_if_fail (IS_PULSEAUDIO_BUTTON (button));
   g_return_if_fail (IS_PULSEAUDIO_VOLUME (button->volume));
@@ -346,6 +434,8 @@ pulseaudio_button_update (PulseaudioButton *button,
   connected = pulseaudio_volume_get_connected (button->volume);
   sink_connected = pulseaudio_volume_get_sink_connected (button->volume);
   recording = pulseaudio_volume_get_recording (button->volume);
+  recording_volume = pulseaudio_volume_get_volume_mic (button->volume);
+  recording_muted = pulseaudio_volume_get_muted_mic (button->volume);
 
   if (!connected)
     icon_name = icons[V_MUTED];
@@ -361,13 +451,20 @@ pulseaudio_button_update (PulseaudioButton *button,
     icon_name = icons[V_HIGH];
 
   if (!connected)
-    tip_text = g_strdup_printf (_("Not connected to the PulseAudio server"));
-  else if (muted)
-    tip_text = g_strdup_printf (_("Volume %d%% (muted)"), (gint) round (volume * 100));
+    recording_icon_name = recording_icons[V_MUTED];
+  else if (recording_muted)
+    recording_icon_name = recording_icons[V_MUTED];
+  else if (recording_volume <= 0.0)
+    recording_icon_name = recording_icons[V_MUTED];
+  else if (recording_volume <= 0.3)
+    recording_icon_name = recording_icons[V_LOW];
+  else if (recording_volume <= 0.7)
+    recording_icon_name = recording_icons[V_MEDIUM];
   else
-    tip_text = g_strdup_printf (_("Volume %d%%"), (gint) round (volume * 100));
-  gtk_widget_set_tooltip_text (GTK_WIDGET (button), tip_text);
-  g_free (tip_text);
+    recording_icon_name = recording_icons[V_HIGH];
+
+  if (!force_update)
+    gtk_tooltip_trigger_tooltip_query (gdk_display_get_default ());
 
   if (force_update || icon_name != button->icon_name)
     {
@@ -376,6 +473,13 @@ pulseaudio_button_update (PulseaudioButton *button,
       gtk_image_set_pixel_size (GTK_IMAGE (button->image), button->icon_size);
     }
 
+  if (force_update || recording_icon_name != button->recording_icon_name)
+    {
+      button->recording_icon_name = recording_icon_name;
+      gtk_image_set_from_icon_name (GTK_IMAGE (button->recording_indicator), recording_icon_name, GTK_ICON_SIZE_BUTTON);
+      gtk_image_set_pixel_size (GTK_IMAGE (button->recording_indicator), button->icon_size);
+    }
+
   if (gtk_widget_get_visible (button->recording_indicator) != recording)
     gtk_widget_set_visible (button->recording_indicator, recording);
 
@@ -396,6 +500,8 @@ pulseaudio_button_set_size (PulseaudioButton *button,
   gtk_widget_set_size_request (GTK_WIDGET (button), size, size);
   button->icon_size = icon_size;
   gtk_image_set_pixel_size (GTK_IMAGE (button->image), button->icon_size);
+  if (gtk_widget_get_visible (button->recording_indicator))
+    gtk_image_set_pixel_size (GTK_IMAGE (button->recording_indicator), button->icon_size);
 }
 
 
@@ -458,6 +564,9 @@ pulseaudio_button_new (PulseaudioPlugin *plugin,
   button->volume_changed_id =
     g_signal_connect_swapped (G_OBJECT (button->volume), "volume-changed",
                               G_CALLBACK (pulseaudio_button_volume_changed), button);
+  button->recording_volume_changed_id =
+    g_signal_connect_swapped (G_OBJECT (button->volume), "volume-mic-changed",
+                              G_CALLBACK (pulseaudio_button_volume_changed), button);
   button->recording_changed_id =
     g_signal_connect_swapped (G_OBJECT (button->volume), "recording-changed",
                               G_CALLBACK (pulseaudio_button_recording_changed), button);
