@@ -237,8 +237,8 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
                               G_OBJECT (object), "active",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
-      object = gtk_builder_get_object (builder, "checkbutton-show-notifications");
-      g_return_if_fail (GTK_IS_CHECK_BUTTON (object));
+      object = gtk_builder_get_object (builder, "combobox-notifications");
+      g_return_if_fail (GTK_IS_COMBO_BOX (object));
 #ifdef HAVE_LIBNOTIFY
       g_object_bind_property (G_OBJECT (dialog->config), "show-notifications",
                               G_OBJECT (object), "active",
@@ -257,6 +257,12 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
       gtk_widget_set_visible (GTK_WIDGET (object), FALSE);
 #endif
 
+      object = gtk_builder_get_object (builder, "spinbutton-volume-step");
+      g_return_if_fail (GTK_IS_ENTRY (object));
+      g_object_bind_property (G_OBJECT (dialog->config), "volume-step",
+                              G_OBJECT (object), "value",
+                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
+
       object = gtk_builder_get_object (builder, "entry-mixer-command");
       g_return_if_fail (GTK_IS_ENTRY (object));
       g_object_bind_property (G_OBJECT (dialog->config), "mixer-command",
@@ -310,37 +316,39 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
               gchar *name = NULL;
               gchar *icon_name = NULL;
               gchar *full_path = NULL;
-              GdkPixbuf *buf = NULL;
+              GIcon *icon = NULL;
 
-              if (pulseaudio_mpris_get_player_summary (players[i], &name, &icon_name, &full_path)) {
-                if (g_file_test (icon_name, G_FILE_TEST_EXISTS) && !g_file_test (icon_name, G_FILE_TEST_IS_DIR)) {
-                  buf = exo_gdk_pixbuf_new_from_file_at_max_size (icon_name, 16, 16, TRUE, NULL);
+              if (pulseaudio_mpris_get_player_summary (players[i], &name, &icon_name, &full_path))
+                {
+                  if (g_file_test (icon_name, G_FILE_TEST_EXISTS) && !g_file_test (icon_name, G_FILE_TEST_IS_DIR))
+                    {
+                      GdkPixbuf *buf = gdk_pixbuf_new_from_file (icon_name, NULL);
+                      if (G_LIKELY (buf != NULL))
+                        icon = G_ICON (buf);
+                    }
+
+                  if (G_LIKELY (icon == NULL))
+                    {
+                      if (gtk_icon_theme_has_icon (gtk_icon_theme_get_default (), icon_name))
+                        icon = g_themed_icon_new (icon_name);
+                      else
+                        icon = g_themed_icon_new_with_default_fallbacks ("audio-player");
+                    }
+
+                  gtk_list_store_append (liststore, &iter);
+                  gtk_list_store_set (liststore, &iter,
+                                      0, icon,
+                                      1, players[i],
+                                      2, name,
+                                      3, pulseaudio_config_player_blacklist_lookup (dialog->config, players[i]),
+                                      -1);
+
+                  g_free (name);
+                  g_free (icon_name);
+                  g_free (full_path);
+                  if (icon != NULL)
+                    g_object_unref (icon);
                 }
-
-                if (!buf) {
-                  GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
-                  buf = gtk_icon_theme_load_icon (icon_theme,
-                                                  icon_name,
-                                                  16,
-                                                  GTK_ICON_LOOKUP_FORCE_SIZE,
-                                                  NULL);
-                  if (!buf) {
-                    buf = gtk_icon_theme_load_icon (icon_theme,
-                                                  "audio-player",
-                                                  16,
-                                                  GTK_ICON_LOOKUP_FORCE_SIZE,
-                                                  NULL);
-                  }
-                }
-
-                gtk_list_store_append(liststore, &iter);
-                gtk_list_store_set(liststore, &iter,
-                                 0, buf,
-                                 1, players[i],
-                                 2, name,
-                                 3, pulseaudio_config_player_blacklist_lookup(dialog->config, players[i]),
-                                 -1);
-              }
             }
         }
       g_strfreev (players);
@@ -355,7 +363,7 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
 
       object = gtk_builder_get_object(builder, "checkbutton-wnck");
       g_return_if_fail(GTK_IS_CHECK_BUTTON(object));
-#ifdef HAVE_WNCK
+#if defined (HAVE_WNCK) || defined (HAVE_LIBXFCE4WINDOWING)
       g_object_bind_property(G_OBJECT(dialog->config), "enable-wnck",
                              G_OBJECT(object), "active",
                              G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
