@@ -156,8 +156,6 @@ pulseaudio_plugin_class_init (PulseaudioPluginClass *klass)
 static void
 pulseaudio_plugin_init (PulseaudioPlugin *pulseaudio_plugin)
 {
-  g_log_set_always_fatal (G_LOG_LEVEL_ERROR);
-
   /* initialize debug logging */
   pulseaudio_plugin_init_debug ();
   pulseaudio_debug("Pulseaudio Panel Plugin initialized");
@@ -231,8 +229,6 @@ pulseaudio_plugin_init_debug (void)
 static void
 pulseaudio_plugin_show_about (XfcePanelPlugin *plugin)
 {
-  GdkPixbuf *icon;
-
   const gchar *auth[] =
     {
       "Andrzej Radecki <andrzejr@xfce.org>",
@@ -247,20 +243,16 @@ pulseaudio_plugin_show_about (XfcePanelPlugin *plugin)
 
   g_return_if_fail (IS_PULSEAUDIO_PLUGIN (plugin));
 
-  icon = xfce_panel_pixbuf_from_source ("xfce4-pulseaudio-plugin", NULL, 32);
   gtk_show_about_dialog (NULL,
-                         "logo",         icon,
-                         "license",      xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
-                         "version",      PACKAGE_VERSION,
-                         "program-name", PACKAGE_NAME,
-                         "comments",     _("Adjust the audio volume of the PulseAudio sound system"),
-                         "website",      "https://docs.xfce.org/panel-plugins/xfce4-pulseaudio-plugin",
-                         "copyright",    _("Copyright \xc2\xa9 2014-2022 Andrzej Radecki et al.\n"),
-                         "authors",      auth,
+                         "logo-icon-name", "xfce4-pulseaudio-plugin",
+                         "license",        xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
+                         "version",        PACKAGE_VERSION,
+                         "program-name",   PACKAGE_NAME,
+                         "comments",       _("Adjust the audio volume of the PulseAudio sound system"),
+                         "website",        "https://docs.xfce.org/panel-plugins/xfce4-pulseaudio-plugin",
+                         "copyright",      _("Copyright \xc2\xa9 2014-2023 Andrzej Radecki et al.\n"),
+                         "authors",        auth,
                          NULL);
-
-  if (icon)
-    g_object_unref (G_OBJECT (icon));
 }
 
 
@@ -360,6 +352,7 @@ pulseaudio_plugin_volume_key_pressed (const char            *keystring,
   PulseaudioPlugin *pulseaudio_plugin = PULSEAUDIO_PLUGIN (user_data);
   gdouble           volume            = pulseaudio_volume_get_volume (pulseaudio_plugin->volume);
   gdouble           volume_step       = pulseaudio_config_get_volume_step (pulseaudio_plugin->config) / 100.0;
+  gboolean          notify            = pulseaudio_volume_get_show_notifications (pulseaudio_plugin->volume, VOLUME_NOTIFICATIONS_OUTPUT);
 
   pulseaudio_debug ("%s pressed", keystring);
 
@@ -367,13 +360,15 @@ pulseaudio_plugin_volume_key_pressed (const char            *keystring,
     pulseaudio_volume_set_volume (pulseaudio_plugin->volume, MIN (volume + volume_step, MAX (volume, 1.0)));
 #ifdef HAVE_LIBNOTIFY
     /* Also send notification when volume is already at 100% */
-    pulseaudio_notify_volume_changed (pulseaudio_plugin->notify, 1, pulseaudio_plugin->volume);
+    if (notify && volume > 1.0 - 2e-3)
+      pulseaudio_notify_volume_changed (pulseaudio_plugin->notify, TRUE, pulseaudio_plugin->volume);
 #endif
   } else if (strcmp (keystring, PULSEAUDIO_PLUGIN_LOWER_VOLUME_KEY) == 0) {
-    pulseaudio_volume_set_volume (pulseaudio_plugin->volume, volume - volume_step);
+    pulseaudio_volume_set_volume (pulseaudio_plugin->volume, MAX (0.0, volume - volume_step));
 #ifdef HAVE_LIBNOTIFY
     /* Also send notification when volume is already at 0% */
-    pulseaudio_notify_volume_changed (pulseaudio_plugin->notify, 1, pulseaudio_plugin->volume);
+    if (notify && volume < 2e-3)
+      pulseaudio_notify_volume_changed (pulseaudio_plugin->notify, TRUE, pulseaudio_plugin->volume);
 #endif
   }
 }
