@@ -57,10 +57,6 @@ static void                 pulseaudio_volume_get_source_output_info_cb (pa_cont
                                                                          const pa_source_output_info *i,
                                                                          int                   eol,
                                                                          void                 *userdata);
-static void                 pulseaudio_volume_move_sink_input           (pa_context           *context,
-                                                                         const                 pa_sink_input_info *i,
-                                                                         int                   eol,
-                                                                         void                 *userdata);
 
 
 
@@ -80,8 +76,10 @@ struct _PulseaudioVolume
   gdouble               volume;
   gboolean              muted;
   gboolean              recording;
+  gboolean              recording_last_state;
 
   gdouble               volume_mic;
+  gdouble               base_volume_mic;
   gboolean              muted_mic;
 
   guint                 reconnect_timer_id;
@@ -161,7 +159,9 @@ pulseaudio_volume_init (PulseaudioVolume *volume)
   volume->volume = 0.0;
   volume->muted = FALSE;
   volume->recording = FALSE;
+  volume->recording_last_state = FALSE;
   volume->volume_mic = 0.0;
+  volume->base_volume_mic = 0.0;
   volume->muted_mic = FALSE;
   volume->reconnect_timer_id = 0;
 
@@ -210,7 +210,7 @@ pulseaudio_volume_sink_info_cb (pa_context         *context,
                                 void               *userdata)
 {
   gboolean  muted;
-  gdouble   vol;
+  gdouble   vol = 0.0;
 
   PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
 
@@ -222,7 +222,8 @@ pulseaudio_volume_sink_info_cb (pa_context         *context,
   volume->sink_index = (guint)i->index;
 
   muted = !!(i->mute);
-  vol = pulseaudio_volume_v2d (volume, i->volume.values[0]);
+  for (guint j = 0; j < i->volume.channels; j++)
+    vol = MAX (vol, pulseaudio_volume_v2d (volume, i->volume.values[j]));
 
   if (volume->muted != muted)
     {
@@ -239,7 +240,8 @@ pulseaudio_volume_sink_info_cb (pa_context         *context,
       volume->volume = vol;
 
       if (volume->sink_connected)
-        g_signal_emit(G_OBJECT(volume), pulseaudio_volume_signals[VOLUME_CHANGED], 0, TRUE);
+        g_signal_emit(G_OBJECT(volume), pulseaudio_volume_signals[VOLUME_CHANGED], 0,
+                      pulseaudio_volume_get_show_notifications (volume, VOLUME_NOTIFICATIONS_OUTPUT));
     }
 
   pulseaudio_debug ("volume: %f, muted: %d", vol, muted);
@@ -255,7 +257,7 @@ pulseaudio_volume_source_info_cb (pa_context           *context,
                                   void                 *userdata)
 {
   gboolean  muted_mic;
-  gdouble   vol_mic;
+  gdouble   vol_mic = 0.0;
 
   PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
 
@@ -267,7 +269,9 @@ pulseaudio_volume_source_info_cb (pa_context           *context,
   volume->source_index = (guint)i->index;
 
   muted_mic = !!(i->mute);
-  vol_mic = pulseaudio_volume_v2d (volume, i->volume.values[0]);
+  for (guint j = 0; j < i->volume.channels; j++)
+    vol_mic = MAX (vol_mic, pulseaudio_volume_v2d (volume, i->volume.values[j]));
+  volume->base_volume_mic = pulseaudio_volume_v2d (volume, i->base_volume);
 
   if (volume->muted_mic != muted_mic)
     {
@@ -284,7 +288,8 @@ pulseaudio_volume_source_info_cb (pa_context           *context,
       volume->volume_mic = vol_mic;
 
       if (volume->source_connected)
-        g_signal_emit(G_OBJECT(volume), pulseaudio_volume_signals[VOLUME_MIC_CHANGED], 0, TRUE);
+        g_signal_emit(G_OBJECT(volume), pulseaudio_volume_signals[VOLUME_MIC_CHANGED], 0,
+                      pulseaudio_volume_get_show_notifications (volume, VOLUME_NOTIFICATIONS_INPUT));
     }
 
   pulseaudio_debug ("volume mic: %f, muted mic: %d", vol_mic, muted_mic);
@@ -303,8 +308,8 @@ pulseaudio_volume_server_info_cb (pa_context           *context,
   if (i == NULL)
     return;
 
-  pulseaudio_volume_set_default_input (volume, i->default_source_name);
-  pulseaudio_volume_set_default_output (volume, i->default_sink_name);
+  pulseaudio_volume_set_default_input (volume, i->default_source_name, FALSE);
+  pulseaudio_volume_set_default_output (volume, i->default_sink_name, FALSE);
 
   pulseaudio_debug ("server: %s@%s, v.%s", i->user_name, i->server_name, i->server_version);
   pa_context_get_sink_info_by_name (context, i->default_sink_name, pulseaudio_volume_sink_info_cb, volume);
@@ -337,7 +342,6 @@ pulseaudio_volume_subscribe_cb (pa_context                   *context,
                                 void                         *userdata)
 {
   PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
-  gboolean recording;
 
   switch (t & PA_SUBSCRIPTION_EVENT_FACILITY_MASK)
     {
@@ -357,13 +361,9 @@ pulseaudio_volume_subscribe_cb (pa_context                   *context,
       break;
 
     case PA_SUBSCRIPTION_EVENT_SOURCE_OUTPUT :
-      recording = volume->recording;
       volume->recording = FALSE;
       pa_context_get_source_output_info_list (context, pulseaudio_volume_get_source_output_info_cb, volume);
 
-      if (volume->recording != recording)
-        g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [RECORDING_CHANGED], 0, volume->recording);
-
       pulseaudio_volume_sink_source_check (volume, context);
       pulseaudio_debug ("received source output event");
       break;
@@ -409,7 +409,14 @@ pulseaudio_volume_get_source_output_info_cb (pa_context                  *contex
   PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
 
   if (eol > 0)
-    return;
+    {
+      if (volume->recording != volume->recording_last_state)
+        {
+          g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [RECORDING_CHANGED], 0, volume->recording);
+          volume->recording_last_state = volume->recording;
+        }
+      return;
+    }
 
   if (i)
     {
@@ -421,7 +428,6 @@ pulseaudio_volume_get_source_output_info_cb (pa_context                  *contex
         }
 
       volume->recording = TRUE;
-      g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [RECORDING_CHANGED], 0, TRUE);
     }
   else
     {
@@ -444,8 +450,8 @@ pulseaudio_volume_get_source_list_cb (pa_context           *context,
   if (eol > 0)
     return;
 
-  /* Ignore sink monitors, not relevant for users */
-  if (i->monitor_of_sink != PA_INVALID_INDEX)
+  /* Ignore sink monitors if it is not a default sink, not relevant for users */
+  if (i->monitor_of_sink != PA_INVALID_INDEX && g_strcmp0 (i->name, volume->default_source_name) != 0)
     return;
 
   g_hash_table_insert (volume->sources, g_strdup (i->name), g_strdup (i->description));
@@ -498,6 +504,9 @@ pulseaudio_volume_context_state_cb (pa_context *context,
 
       pa_context_get_server_info (volume->pa_context, pulseaudio_volume_get_server_info_cb, volume);
 
+      // Check here if recording is active
+      pa_context_get_source_output_info_list (context, pulseaudio_volume_get_source_output_info_cb, volume);
+
       break;
 
     case PA_CONTEXT_FAILED       :
@@ -508,7 +517,9 @@ pulseaudio_volume_context_state_cb (pa_context *context,
       volume->volume = 0.0;
       volume->muted = FALSE;
       volume->recording = FALSE;
+      volume->recording_last_state = FALSE;
       volume->volume_mic = 0.0;
+      volume->base_volume_mic = 0.0;
       volume->muted_mic = FALSE;
 
       g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [VOLUME_CHANGED], 0, FALSE);
@@ -685,7 +696,8 @@ pulseaudio_volume_sink_volume_changed (pa_context *context,
 
   if (success)
     {
-      g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [VOLUME_CHANGED], 0, TRUE);
+      g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [VOLUME_CHANGED], 0,
+                     pulseaudio_volume_get_show_notifications (volume, VOLUME_NOTIFICATIONS_OUTPUT));
 #ifdef HAVE_LIBCANBERRA
       pulseaudio_plugin_play_sound (volume->plugin, "audio-volume-change", "volume changed");
 #endif
@@ -741,7 +753,8 @@ pulseaudio_volume_source_volume_changed (pa_context *context,
   PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
 
   if (success)
-    g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [VOLUME_MIC_CHANGED], 0, TRUE);
+    g_signal_emit (G_OBJECT (volume), pulseaudio_volume_signals [VOLUME_MIC_CHANGED], 0,
+                   pulseaudio_volume_get_show_notifications (volume, VOLUME_NOTIFICATIONS_INPUT));
 }
 
 
@@ -851,6 +864,16 @@ pulseaudio_volume_get_volume_mic (PulseaudioVolume *volume)
 
 
 
+gdouble
+pulseaudio_volume_get_base_volume_mic (PulseaudioVolume *volume)
+{
+  g_return_val_if_fail (IS_PULSEAUDIO_VOLUME (volume), 0.0);
+
+  return volume->base_volume_mic;
+}
+
+
+
 /* volume setting callbacks */
 /* pa_source_info_cb_t */
 static void
@@ -988,110 +1011,57 @@ pulseaudio_volume_get_default_input (PulseaudioVolume *volume)
 
 
 
-static void
-pulseaudio_volume_default_sink_changed_info_cb (pa_context         *context,
-                                                const pa_sink_info *i,
-                                                int                 eol,
-                                                void               *userdata)
-{
-  PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
-
-  if (i == NULL)
-    return;
-
-  pa_context_move_sink_input_by_index (context, volume->sink_index, i->index, NULL, NULL);
-  volume->sink_index = (guint)i->index;
-
-  pa_context_get_sink_input_info_list (volume->pa_context, pulseaudio_volume_move_sink_input, volume);
-}
-
-
-
-static void
-pulseaudio_volume_default_sink_changed (pa_context *context,
-                                        int         success,
-                                        void       *userdata)
-{
-  PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
-
-  if (success)
-    pa_context_get_sink_info_by_name (volume->pa_context, volume->default_sink_name, pulseaudio_volume_default_sink_changed_info_cb, volume);
-}
-
-
-
-static void
-pulseaudio_volume_move_sink_input (pa_context               *context,
-                                   const pa_sink_input_info *i,
-                                   int                       eol,
-                                   void                     *userdata)
-{
-  PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
-
-  if (i == NULL) return;
-  if (eol > 0) return;
-
-  pa_context_move_sink_input_by_name (context, i->index, volume->default_sink_name, NULL, NULL);
-}
-
-
-
 void
 pulseaudio_volume_set_default_output (PulseaudioVolume *volume,
-                                      const gchar      *name)
+                                      const gchar      *name,
+                                      gboolean          make_default)
 {
   if (g_strcmp0(name, volume->default_sink_name) == 0)
     return;
 
-  g_free (volume->default_sink_name);
-  volume->default_sink_name = g_strdup (name);
-
-  pa_context_set_default_sink (volume->pa_context, name, pulseaudio_volume_default_sink_changed, volume);
-}
-
-
-
-static void
-pulseaudio_volume_default_source_changed_info_cb (pa_context         *context,
-                                                  const pa_source_info *i,
-                                                  int                 eol,
-                                                  void               *userdata)
-{
-  PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
-
-  if (i == NULL)
-    return;
-
-  pa_context_move_source_output_by_index (context, volume->source_index, i->index, NULL, NULL);
-  volume->source_index = (guint)i->index;
-}
-
-
-
-static void
-pulseaudio_volume_default_source_changed (pa_context *context,
-                                          int         success,
-                                          void       *userdata)
-{
-  PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
-
-  if (success)
-    pa_context_get_source_info_by_name (volume->pa_context, volume->default_source_name, pulseaudio_volume_default_source_changed_info_cb, volume);
+  if (make_default)
+    {
+      /* "default_sink_name" will be updated in "else" called from "pulseaudio_volume_subscribe_cb" callback */
+      pa_context_set_default_sink (volume->pa_context, name, NULL, volume);
+    }
+  else
+    {
+      g_free (volume->default_sink_name);
+      volume->default_sink_name = g_strdup (name);
+    }
 }
 
 
 
 void
 pulseaudio_volume_set_default_input (PulseaudioVolume *volume,
-                                     const gchar      *name)
+                                     const gchar      *name,
+                                     gboolean          make_default)
 {
   if (g_strcmp0 (name, volume->default_source_name) == 0)
     return;
 
-  g_free (volume->default_source_name);
-  volume->default_source_name = g_strdup (name);
+  if (make_default)
+    {
+      /* "default_source_name" will be updated in "else" called from "pulseaudio_volume_subscribe_cb" callback */
+      pa_context_set_default_source (volume->pa_context, name, NULL, volume);
+    }
+  else
+    {
+      g_free (volume->default_source_name);
+      volume->default_source_name = g_strdup (name);
+    }
+}
 
-  pa_context_set_default_source (volume->pa_context, name, pulseaudio_volume_default_source_changed, volume);
+
+
+gboolean
+pulseaudio_volume_get_show_notifications (PulseaudioVolume *volume,
+                                          guint             direction)
+{
+  guint show_notifications = pulseaudio_config_get_show_notifications (volume->config);
+  return show_notifications != VOLUME_NOTIFICATIONS_NONE
+    && (show_notifications == VOLUME_NOTIFICATIONS_ALL || show_notifications == direction);
 }
 
 
