@@ -56,6 +56,7 @@ void                    pulseaudio_volume_set_muted               (PulseaudioVol
 void                    pulseaudio_volume_toggle_muted            (PulseaudioVolume *volume);
 
 gdouble                 pulseaudio_volume_get_volume_mic          (PulseaudioVolume *volume);
+gdouble                 pulseaudio_volume_get_base_volume_mic     (PulseaudioVolume *volume);
 void                    pulseaudio_volume_set_volume_mic          (PulseaudioVolume *volume,
                                                                    gdouble           vol);
 
@@ -69,14 +70,18 @@ gchar                  *pulseaudio_volume_get_output_by_name      (PulseaudioVol
                                                                    gchar            *name);
 const gchar            *pulseaudio_volume_get_default_output      (PulseaudioVolume *volume);
 void                    pulseaudio_volume_set_default_output      (PulseaudioVolume *volume,
-                                                                   const gchar      *name);
+                                                                   const gchar      *name,
+                                                                   gboolean          make_default);
 
 GList                  *pulseaudio_volume_get_input_list          (PulseaudioVolume *volume);
 gchar                  *pulseaudio_volume_get_input_by_name       (PulseaudioVolume *volume,
                                                                    gchar            *name);
 const gchar            *pulseaudio_volume_get_default_input       (PulseaudioVolume *volume);
 void                    pulseaudio_volume_set_default_input       (PulseaudioVolume *volume,
-                                                                   const gchar      *name);
+                                                                   const gchar      *name,
+                                                                   gboolean          make_default);
+gboolean                pulseaudio_volume_get_show_notifications  (PulseaudioVolume *volume,
+                                                                   guint direction);
 
 G_END_DECLS
 
